@@ -24,9 +24,8 @@ class DagCRUD:
         db: Session,
         dag: DagCreate,
     ) -> models.Task:
-
         head_task = models.Task(
-            id=uuid.uuid4().hex,
+            id=uuid.uuid4(),
             task_type='dag',
             worker=read_worker(db, 'dag'),
             status=TaskStatus.PENDING,
@@ -37,7 +36,6 @@ class DagCRUD:
         for task_input_data_id in graphlib.TopologicalSorter(dag.graph).static_order():
             input_data = dag.tasks_input_data[task_input_data_id]
             db_task = models.Task(
-                id=uuid.uuid4().hex,
                 task_type=dag.task_type,
                 input_data=input_data,
                 worker=read_worker(db, input_data.pop('worker_name')),
