@@ -24,7 +24,7 @@ class WithDuration(BaseModel):
             if stopped_at is not None:
                 values['duration_seconds'] = (stopped_at - started_at).total_seconds()
             else:
-                values['duration_seconds'] = (datetime.datetime.now() - started_at).total_seconds()
+                values['duration_seconds'] = (datetime.datetime.now(tz=datetime.UTC) - started_at).total_seconds()
         return values
 
 # =============================================================================
@@ -60,17 +60,12 @@ class TaskCreate(WithWorkerName):
     id: UUID = Field(default_factory=uuid.uuid4)
     dag_id: UUID | None = None
     upstream: list[UUID] = []
-    # dag_tasks: list[str] | None = None
-    # is_dag_head: bool = False
     task_type: str | None = None
     input_data: dict | None = None
     worker_id: UUID | None = None
 
     @root_validator(pre=True)
     def validate_task_type_and_input_data(cls, values):
-        # if 'task_type' not in values or values['task_type'] is None:
-        #     return values
-        # raise ValueError('task_type must be set')
         task_type = values['task_type']
         if task_type not in TASK_TYPE_TO_INPUT_DATA_SCHEMA:
             raise ValueError(f'unsupported task type {task_type}')
@@ -85,12 +80,6 @@ class TaskCreate(WithWorkerName):
         input_data_schema.validate(values['input_data'])
         return values
 
-    # @root_validator
-    # def validate_dag_tasks(cls, values):
-    #     if values.get('is_dag_head') and values.get('dag_tasks') is None:
-    #         raise ValueError('dag_tasks must be set for dag head')
-    #     return values
-
 
 class Task(TaskCreate, WithDuration):
     dag_id: UUID | None
@@ -109,7 +98,6 @@ class Task(TaskCreate, WithDuration):
 class TaskUpdate(BaseModel):
     started_at: datetime.datetime | None
     stopped_at: datetime.datetime | None
-    # updated_at: datetime.datetime
     status: TaskStatus | None
     output_data: dict | None = None
     worker_id: UUID | None = None
@@ -140,26 +128,6 @@ class DagCreate(BaseModel):
         return values
 
 
-# class Dag(WithDuration):
-#     id: str
-#     created_at: datetime.datetime
-#     updated_at: datetime.datetime
-#     started_at: datetime.datetime | None
-#     stopped_at: datetime.datetime | None
-#     status: TaskStatus
-#     graph: dict[str, list[str]]
-#     tasks: list[str]
-
-#     class Config:
-#         orm_mode = True
-
-
-# class DagUpdate(BaseModel):
-#     started_at: datetime.datetime | None
-#     stopped_at: datetime.datetime | None
-#     status: TaskStatus | None
-
-
 # =============================================================================
 
 
